model_file_path

Function model_file_path 

pub fn model_file_path(
    layout: &ModelCacheLayout,
    model_dir: &str,
    file_name: &str,
) -> Option<PathBuf>
Resolve the expected path for a specific model file within the cache.

Returns None if the model directory name is not in the known layout.