pub fn resolve_cache_root() -> PathBufExpand description
Resolve the model cache root directory using the priority chain.
Does NOT create directories — use ensure_cache_layout for that.
pub fn resolve_cache_root() -> PathBufResolve the model cache root directory using the priority chain.
Does NOT create directories — use ensure_cache_layout for that.