ModelCacheLayout

Struct ModelCacheLayout 

pub struct ModelCacheLayout {
    pub root: PathBuf,
    pub model_dirs: Vec<ModelDirEntry>,
}
Description of the full cache directory tree.

Fields

root: PathBuf

Root directory of the model cache.

model_dirs: Vec<ModelDirEntry>

Per-model versioned directories.

Implementations

Source

impl ModelCacheLayout

pub fn for_root(root: PathBuf) -> Self

Build the layout description for a given root.

pub fn default_layout() -> Self

Build the layout using the default resolved root.

pub fn model_path(&self, dir_name: &str) -> Option<&Path>

Get the base path for a model by directory name.

pub fn versioned_model_path(&self, dir_name: &str) -> Option<PathBuf>

Get the versioned path for a model by directory name.

pub fn model_base_path(&self, dir_name: &str) -> Option<PathBuf>

Get the model’s parent directory (without the version suffix).