pub fn model_file_path(
layout: &ModelCacheLayout,
model_dir: &str,
file_name: &str,
) -> Option<PathBuf>Expand description
Resolve the expected path for a specific model file within the cache.
Returns None if the model directory name is not in the known layout.