pub struct ModelCacheLayout {
pub root: PathBuf,
pub model_dirs: Vec<ModelDirEntry>,
}Expand description
Description of the full cache directory tree.
Fields
root: PathBufRoot directory of the model cache.
model_dirs: Vec<ModelDirEntry>Per-model versioned directories.
Implementations
Sourceimpl ModelCacheLayout
impl ModelCacheLayout
Sourcepub fn default_layout() -> Self
pub fn default_layout() -> Self
Build the layout using the default resolved root.
Sourcepub fn model_path(&self, dir_name: &str) -> Option<&Path>
pub fn model_path(&self, dir_name: &str) -> Option<&Path>
Get the base path for a model by directory name.
Sourcepub fn versioned_model_path(&self, dir_name: &str) -> Option<PathBuf>
pub fn versioned_model_path(&self, dir_name: &str) -> Option<PathBuf>
Get the versioned path for a model by directory name.
Sourcepub fn model_base_path(&self, dir_name: &str) -> Option<PathBuf>
pub fn model_base_path(&self, dir_name: &str) -> Option<PathBuf>
Get the model’s parent directory (without the version suffix).